@@ -2,7 +2,7 @@ __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 __title__ = 'qq'
 __author__ = 'Foxwhite'
 __license__ = 'MIT'
-__version__ = '1.0.1'
+__version__ = '1.0.4'
 
 import logging
 from typing import NamedTuple
@@ -24,6 +24,8 @@ from .shard import *
 from .error import *
 from .embeds import *
 from .mention import *
+from .partial_emoji import *
+from .raw_models import *
 
 
 class VersionInfo(NamedTuple):
@@ -34,4 +36,4 @@ class VersionInfo(NamedTuple):
     serial: int
 
 
-version_info: VersionInfo = VersionInfo(major=1, minor=0, micro=1, releaselevel='beta', serial=0)
+version_info: VersionInfo = VersionInfo(major=1, minor=0, micro=4, releaselevel='beta', serial=0)
