@@ -11,13 +11,14 @@ import aiohttp
 import requests
 
 from . import __version__, utils
-from.embeds import Ark
+from .role import Role
+from .embeds import Ark, Embed
 from .types.member import MemberWithUser as MemberPayload
 from .error import HTTPException, Forbidden, NotFound, QQServerError, LoginFailure, GatewayNotFound
 from .gateway import QQClientWebSocketResponse
 from .types.message import Message
 from .types import user, guild, message, channel, member
-from .types.embed import Ark as ArkPayload
+from .types.embed import Ark as ArkPayload, Embed as EmbedPayload
 from .utils import MISSING
 from .types.channel import Channel as ChannelPayload
 from .types.role import Role as RolePayload
@@ -247,6 +248,8 @@ class HTTPClient:
         if self.token is not None:
             headers['Authorization'] = 'Bot ' + self.token
         rsp = requests.get(f'https://api.sgroup.qq.com/users/@me/guilds', headers=headers)
+        _log.debug('GET %s 与 %s 已返回 %s', f'https://api.sgroup.qq.com/users/@me/guilds', rsp.json(),
+                   rsp.status_code)
         return rsp.json()
 
     def sync_get_bot_member(self,guild_id: int, user_id: int) -> MemberPayload:
@@ -290,12 +293,12 @@ class HTTPClient:
 
     # 身份组管理
 
-    def get_roles(self, guild_id: int) -> Response[List[role.Role]]:
+    def get_roles(self, guild_id: int) -> Response[List[Role]]:
         return self.request(Route('GET', '/guilds/{guild_id}/roles', guild_id=guild_id))
 
     def edit_role(
             self, guild_id: int, role_id: int, *, reason: Optional[str] = None, **fields: Any
-    ) -> Response[role.Role]:
+    ) -> Response[Role]:
         r = Route('PATCH', '/guilds/{guild_id}/roles/{role_id}', guild_id=guild_id, role_id=role_id)
         valid_keys = ('name', 'color', 'hoist')
         payload = {"info": {k: v for k, v in fields.items() if k in valid_keys}}
@@ -305,7 +308,7 @@ class HTTPClient:
         r = Route('DELETE', '/guilds/{guild_id}/roles/{role_id}', guild_id=guild_id, role_id=role_id)
         return self.request(r, reason=reason)
 
-    def create_role(self, guild_id: int, *, reason: Optional[str] = None, **fields: Any) -> Response[role.Role]:
+    def create_role(self, guild_id: int, *, reason: Optional[str] = None, **fields: Any) -> Response[Role]:
         r = Route('POST', '/guilds/{guild_id}/roles', guild_id=guild_id)
         return self.request(r, json=fields, reason=reason)
 
@@ -461,6 +464,7 @@ class HTTPClient:
             content: Optional[str],
             image_url: Optional[str],
             ark: Optional[Union[Ark, ArkPayload]],
+            embed: Optional[Union[Embed, EmbedPayload]],
             *,
             tts: bool = False,
             message_reference: Optional[message.MessageReference] = None,
@@ -485,6 +489,11 @@ class HTTPClient:
                 ark = ark.to_dict()
             payload['ark'] = ark
 
+        if embed:
+            if isinstance(embed, Embed):
+                embed = embed.to_dict()
+            payload['embed'] = embed
+
         return self.request(r, json=payload)
 
     def get_members(
