@@ -14,13 +14,15 @@ from .channel import PartialMessageable, TextChannel, _channel_factory
 from .flags import Intents
 from .mention import AllowedMentions
 from .object import Object
+from .partial_emoji import PartialEmoji
+from .raw_models import RawReactionActionEvent, RawReactionClearEvent, RawReactionClearEmojiEvent
 from .user import User, ClientUser
 from .guild import Guild
 from .message import Message
 from .member import Member
 
 if TYPE_CHECKING:
-    from .abc import GuildChannel
+    from .abc import GuildChannel, MessageableChannel
     from .http import HTTPClient
     from .client import Client
     from .gateway import QQWebSocket
@@ -266,6 +268,14 @@ class ConnectionState:
         channel = guild and guild._resolve_channel(channel_id)
         return channel or PartialMessageable(state=self, id=channel_id), guild
 
+    def get_reaction_emoji(self, data) -> Union[PartialEmoji]:
+        emoji_id = data.get('id')
+
+        if not emoji_id:
+            return data['name']
+
+        return PartialEmoji.with_state(self, animated=data.get('animated', False), id=emoji_id, name=data['name'])
+
     async def chunker(
             self, guild_id: int, query: str = '', limit: int = 0, presences: bool = False, *,
             nonce: Optional[str] = None
@@ -580,6 +590,79 @@ class ConnectionState:
     def parse_audio_off_mic(self, data) -> None:
         self.dispatch('mic_stop', data)
 
+    def parse_message_reaction_add(self, data) -> None:
+        emoji = data['emoji']
+        emoji_id = emoji.get('id')
+        emoji = PartialEmoji.with_state(self, id=emoji_id, custom=True if emoji['type'] == '1' else False)
+        raw = RawReactionActionEvent(data, emoji, 'REACTION_ADD')
+
+        member_data = data.get('member')
+        if member_data:
+            guild = self._get_guild(raw.guild_id)
+            if guild is not None:
+                raw.member = Member(data=member_data, guild=guild, state=self)
+            else:
+                raw.member = None
+        else:
+            raw.member = None
+        self.dispatch('raw_reaction_add', raw)
+
+        # rich interface here
+        message = self._get_message(raw.message_id)
+        if message is not None:
+            emoji = self._upgrade_partial_emoji(emoji)
+            reaction = message._add_reaction(data, emoji, raw.user_id)
+            user = raw.member or self._get_reaction_user(message.channel, raw.user_id)
+
+            if user:
+                self.dispatch('reaction_add', reaction, user)
+
+    def parse_message_reaction_remove_all(self, data) -> None:
+        raw = RawReactionClearEvent(data)
+        self.dispatch('raw_reaction_clear', raw)
+
+        message = self._get_message(raw.message_id)
+        if message is not None:
+            old_reactions = message.reactions.copy()
+            message.reactions.clear()
+            self.dispatch('reaction_clear', message, old_reactions)
+
+    def parse_message_reaction_remove(self, data) -> None:
+        emoji = data['emoji']
+        emoji_id = emoji.get('id')
+        emoji = PartialEmoji.with_state(self, id=emoji_id, custom=True if emoji['type'] == '1' else False)
+        raw = RawReactionActionEvent(data, emoji, 'REACTION_REMOVE')
+        self.dispatch('raw_reaction_remove', raw)
+
+        message = self._get_message(raw.message_id)
+        if message is not None:
+            emoji = self._upgrade_partial_emoji(emoji)
+            try:
+                reaction = message._remove_reaction(data, emoji, raw.user_id)
+            except (AttributeError, ValueError):  # eventual consistency lol
+                pass
+            else:
+                user = self._get_reaction_user(message.channel, raw.user_id)
+                if user:
+                    self.dispatch('reaction_remove', reaction, user)
+
+    def parse_message_reaction_remove_emoji(self, data) -> None:
+        emoji = data['emoji']
+        emoji_id = emoji.get('id')
+        emoji = PartialEmoji.with_state(self, id=emoji_id, custom=True if emoji['type'] == '1' else False)
+        raw = RawReactionClearEmojiEvent(data, emoji)
+        self.dispatch('raw_reaction_clear_emoji', raw)
+
+        message = self._get_message(raw.message_id)
+        if message is not None:
+            try:
+                reaction = message._clear_emoji(emoji)
+            except (AttributeError, ValueError):  # eventual consistency lol
+                pass
+            else:
+                if reaction:
+                    self.dispatch('reaction_clear_emoji', reaction)
+
     def get_channel(self, id: Optional[int]) -> Optional[Union[Channel]]:
         if id is None:
             return None
@@ -594,6 +677,18 @@ class ConnectionState:
     ) -> Message:
         return Message(state=self, channel=channel, data=data)
 
+    def _upgrade_partial_emoji(self, emoji: PartialEmoji) -> Union[PartialEmoji, str]:
+        emoji_id = emoji.id
+        if not emoji_id:
+            return emoji.name
+
+        return emoji
+
+    def _get_reaction_user(self, channel: MessageableChannel, user_id: int) -> Optional[Union[User, Member]]:
+        if isinstance(channel, TextChannel):
+            return channel.guild.get_member(user_id)
+        return self.get_user(user_id)
+
 
 class AutoShardedConnectionState(ConnectionState):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
